@@ -8,20 +8,20 @@ use thiserror::Error;
 use crate::config::{Config, TemplateSlotsTable};
 
 #[derive(Debug)]
-pub(crate) struct TemplateSlots {
+pub struct TemplateSlots {
     pub(crate) var_name: String,
     pub(crate) var_info: VarInfo,
     pub(crate) prompt: String,
 }
 
 #[derive(Debug, Clone)]
-pub(crate) enum VarInfo {
+pub enum VarInfo {
     Bool { default: Option<bool> },
     String { entry: Box<StringEntry> },
 }
 
 #[derive(Debug, Clone)]
-pub(crate) struct StringEntry {
+pub struct StringEntry {
     pub(crate) default: Option<String>,
     pub(crate) choices: Option<Vec<String>>,
     pub(crate) regex: Option<Regex>,
@@ -85,10 +85,9 @@ const RESERVED_NAMES: [&str; 5] = [
     "crate_type",
 ];
 
-pub(crate) fn fill_project_variables<F>(
+pub fn fill_project_variables<F>(
     mut template_object: Object,
     template_config: &Config,
-    silent: bool,
     value_provider: F,
 ) -> Result<Object>
 where
@@ -105,17 +104,11 @@ where
 
         match template_object.entry(key) {
             Entry::Occupied(_) => (), // we already have the value from the config file
-            Entry::Vacant(entry) if !silent => {
+            Entry::Vacant(entry) => {
                 // we don't have the file from the config and we can ask for it
                 let value = value_provider(&slot)?;
-
                 entry.insert(value);
             }
-            Entry::Vacant(_) => {
-                anyhow::bail!(ConversionError::MissingPlaceholderVariable {
-                    var_name: slot.var_name
-                })
-            }
         }
     }
 
